## The following vectors are for runN where N=1,...,8
## 
## (1) 0.5,0.5,0.01,0.01,0  <<< these are variances and rho (non-standard!!)
## (2) 0.75,0.5,0.01,0.01,0 <<< and so forth
## (3) 0.75,0.75,0.01,0.01,0 <<< note that the psisquiggle notation is in terms of
## (4) 0.9,0.9,0.01,0.01,0 <<< standard deviations
## (5) 0.5,0.5,0.1024,0.01,0
## (6) 0.6,0.6,0.01,0.1024,0
## (7) 0.9,0.1,0.1024,0.1024,0
## (8) 0.5,0.5,0.01,0.01,0.3


allcheck.king <- function (times=100,mean.beta.b.squiggle=.5,mean.beta.w.squiggle=.5,sigmasq.beta.b.squiggle=.01,sigmasq.beta.w.squiggle=.01,rho.bw.squiggle=0) {

  ## NOTE: variances are passed, not standard deviations
  
  ## Format for results is
  ##
  ## column 1 = gamma.real
  ## column 2 = gamma.est
  ## column 3 = gamma.adjust
  ##
  ## these three variables come from the function check.1
  
  results _ matrix(0,nrow=times,ncol=3)
  for (i in 1:times) {
    cat ("iteration ",i,"of ",times,"\n")
    results[i,1:3]_t(as.matrix(check.1.king(mean.beta.b.squiggle,mean.beta.w.squiggle,sigmasq.beta.b.squiggle,sigmasq.beta.w.squiggle,rho.bw.squiggle)))
  }

  diff.est_abs(results[,1]-results[,2])
  diff.adjust_abs(results[,1]-results[,3])

  mse.est_mean(results[,1]-results[,2])^2
  mse.adjust_mean(results[,1]-results[,3])^2
  
  ratio.est_results[,2]/results[,1]
  ratio.adjust_results[,3]/results[,1]  
  
  times.we.win_sum(diff.adjust<diff.est)
  avg.error.est_mean(diff.est)
  avg.error.adjust_mean(diff.adjust)
  avg.rel_mean(diff.adjust/diff.est)

  avg.ratio.est_mean(ratio.est)
  avg.ratio.adjust_mean(ratio.adjust)

  ## return overall results of the simulations
  
  c(mean.beta.b.squiggle,mean.beta.w.squiggle,sigmasq.beta.b.squiggle,sigmasq.beta.w.squiggle,rho.bw.squiggle,times,times.we.win,avg.error.est,avg.error.adjust,avg.rel,avg.ratio.est,avg.ratio.adjust,mse.est,mse.adjust)
  
}

allcheck.noinfo.king <- function (times=100,mean.beta.b.squiggle=.5,mean.beta.w.squiggle=.5,sigmasq.beta.b.squiggle=.01,sigmasq.beta.w.squiggle=.01,rho.bw.squiggle=.3) {

  ## NOTE: variances are passed, not standard deviations
  
  ## Format for results is
  ##
  ## column 1 = gamma.real
  ## column 2 = gamma.est
  ## column 3 = gamma.adjust
  ##
  ## these three variables come from the function check.1
  
  results _ matrix(0,nrow=times,ncol=3)
  for (i in 1:times) {
    cat ("iteration ",i,"of ",times,"\n")
    results[i,1:3]_t(as.matrix(check.1.noinfo.king(mean.beta.b.squiggle,mean.beta.w.squiggle,sigmasq.beta.b.squiggle,sigmasq.beta.w.squiggle,rho.bw.squiggle)))
  }

  diff.est_abs(results[,1]-results[,2])
  diff.adjust_abs(results[,1]-results[,3])

  mse.est_mean(results[,1]-results[,2])^2
  mse.adjust_mean(results[,1]-results[,3])^2
  
  ratio.est_results[,2]/results[,1]
  ratio.adjust_results[,3]/results[,1]  
  
  times.we.win_sum(diff.adjust<diff.est)
  avg.error.est_mean(diff.est)
  avg.error.adjust_mean(diff.adjust)
  avg.rel_mean(diff.adjust/diff.est)

  avg.ratio.est_mean(ratio.est)
  avg.ratio.adjust_mean(ratio.adjust)

  ## return overall results of the simulations
  
  c(mean.beta.b.squiggle,mean.beta.w.squiggle,sigmasq.beta.b.squiggle,sigmasq.beta.w.squiggle,rho.bw.squiggle,times,times.we.win,avg.error.est,avg.error.adjust,avg.rel,avg.ratio.est,avg.ratio.adjust,mse.est,mse.adjust)
  
}


allcheck.mccue <- function (times=100,mean.beta.b.squiggle=.5,mean.beta.w.squiggle=.5,sigmasq.beta.b.squiggle=.01,sigmasq.beta.w.squiggle=.01,rho.bw.squiggle=0) {

  ## NOTE: variances are passed, not standard deviations
  
  ## Format for results is
  ##
  ## column 1 = gamma.real
  ## column 2 = gamma.est
  ## column 3 = gamma.adjust
  ##
  ## these three variables come from the function check.1
  
  results _ matrix(0,nrow=times,ncol=3)
  for (i in 1:times) {
    cat ("iteration ",i,"of ",times,"\n")
    results[i,1:3]_t(as.matrix(check.1.mccue(mean.beta.b.squiggle,mean.beta.w.squiggle,sigmasq.beta.b.squiggle,sigmasq.beta.w.squiggle,rho.bw.squiggle)))
  }

  diff.est_abs(results[,1]-results[,2])
  diff.adjust_abs(results[,1]-results[,3])

  mse.est_mean(results[,1]-results[,2])^2
  mse.adjust_mean(results[,1]-results[,3])^2
  
  ratio.est_results[,2]/results[,1]
  ratio.adjust_results[,3]/results[,1]  
  
  times.we.win_sum(diff.adjust<diff.est)
  avg.error.est_mean(diff.est)
  avg.error.adjust_mean(diff.adjust)
  avg.rel_mean(diff.adjust/diff.est)

  avg.ratio.est_mean(ratio.est)
  avg.ratio.adjust_mean(ratio.adjust)

  ## return overall results of the simulations
  
  c(mean.beta.b.squiggle,mean.beta.w.squiggle,sigmasq.beta.b.squiggle,sigmasq.beta.w.squiggle,rho.bw.squiggle,times,times.we.win,avg.error.est,avg.error.adjust,avg.rel,avg.ratio.est,avg.ratio.adjust,mse.est,mse.adjust)
  
}
