check.1.king <- function (mean.beta.b.squiggle=.5,mean.beta.w.squiggle=.5,sigmasq.beta.b.squiggle=.01,sigmasq.beta.w.squiggle=.01,rho.bw.squiggle=0) {

  ## NOTE: variances are passed, not standard deviations
  
  n_5000                                # number of simulated districts
  alpha_0                               # second stage parameters
  gammacoef_1

  ## 1.  set psi squiggle parameters

  covar.bw.squiggle_
    rho.bw.squiggle*sqrt(sigmasq.beta.b.squiggle)*sqrt(sigmasq.beta.w.squiggle)
 
  ## 2. get psi parameters via simuation
  
  mu_c(mean.beta.b.squiggle,mean.beta.w.squiggle) # form mean 
  sig_matrix(nrow=2,ncol=2,             # and covariance matrices of squiggle normal
             c(sigmasq.beta.b.squiggle,covar.bw.squiggle,covar.bw.squiggle,sigmasq.beta.w.squiggle))

  temp.data_rmultnorm(n=50000,mu=mu,vmat=sig) # get normal draws from squiggle
  pitch_(temp.data[,1]<0 | temp.data[,1]>1 | temp.data[,2]<0 | temp.data[,2]>1)
  cat ("Throwing away ",sum(pitch==1)," observations...\n")
  temp.data_temp.data[as.logical(1-pitch),] # pitch the bad rows based on [0,1]

  mean.beta.b_mean(temp.data[,1])       # these are the non-squiggle 
  mean.beta.w_mean(temp.data[,2])       # parameters
  sigmasq.beta.b_var(temp.data[,1])
  sigmasq.beta.w_var(temp.data[,2])
  rho.bw_cor(temp.data[,1],temp.data[,2])
  covar.bw_cov(temp.data[,1],temp.data[,2])
  
  index_c(1:length(temp.data[,1]))      # list of numbers, length of temp.data
  use.these.observations_sample(index,size=n,replace=F)
  
  real.beta.b_temp.data[use.these.observations,1]
  real.beta.w_temp.data[use.these.observations,2]
  
  ## 3. get random xi and implied new ti

  xi_runif(n,min=0,max=1)
  
  ti_real.beta.b*xi+real.beta.w*(1-xi)
  
  omegai_sigmasq.beta.b.squiggle*xi+covar.bw.squiggle*(1-xi) # page 108
  epsiloni_ti-mean.beta.b.squiggle*xi-mean.beta.w.squiggle*(1-xi) # page 108
  sigmasqi_sigmasq.beta.w.squiggle+     # page 106
    (2*covar.bw.squiggle-2*sigmasq.beta.w.squiggle)*xi+
    (sigmasq.beta.b.squiggle+sigmasq.beta.w.squiggle-2*covar.bw.squiggle)*(xi^2)
  
  ## 4.  calculate estimated beta.b and its estimation error.  To do this,
  ## first calculate the mean and variance terms from equation C.1 on page 304.
  ## These we call bigmu and bigsigmasq.  Then, calculate the truncation points based
  ## on page 79.  Then, using eq 13.134 of Johnson, Kotz, and Balakrishnan
  ## Vol 1 page 156, we calculate the mean of the truncated normal.

  cat ("Getting ancillary parameter values...\n")
  
  bigmu_mean.beta.b.squiggle+(omegai/sigmasqi)*epsiloni
  bigsigmasq_sigmasq.beta.b.squiggle-omegai^2/sigmasqi

  ## get bounds (p. 79)

  zeros_rep(0,times=n)
  templow_rbind(zeros,(ti-(1-xi))/xi)
  lower_apply (templow,2,max)

  ones_rep(1,times=n)
  temphigh_rbind(ones,ti/xi)
  upper_apply(temphigh,2,min)

  ## set temporary parameters

  bigsigma_sqrt(bigsigmasq)             # take the square root only once!
  aterm_(lower-bigmu)/bigsigma
  bterm_(upper-bigmu)/bigsigma

  est.beta.b_bigmu+(dnorm(aterm)-dnorm(bterm))/(pnorm(bterm)-pnorm(aterm))*bigsigma
  error.beta.b_est.beta.b-real.beta.b
  
  ## 5. get implied covariate vector

  zetai_rnorm(n,mean=0,sd=1)            # second stage disturbance vector

  ## zi_c(1:n)
  ## zi[real.beta.b>=.75]_real.beta.b[real.beta.b>=.75]
  ## zi[real.beta.b<.75 && real.beta.b>=.5]_.5*real.beta.b[real.beta.b<.75 && real.beta.b>=.5]
  ## zi[real.beta.b<.5]_.45*real.beta.b[real.beta.b<.5]

  zi_real.beta.b+rnorm(n,mean=0,sd=.5)
  
  fit.real_lm(real.beta.b~zi)
  gamma.real_fit.real$coef[2]
  fit.est_lm(est.beta.b~zi)
  gamma.est_fit.est$coef[2]
  
  fit.temp_lm(error.beta.b~real.beta.b)
  delta.b.zero_fit.temp$coef[1]
  delta.b.one_fit.temp$coef[2]

  gamma.adjust_gamma.est/(1+delta.b.one)

  c(gamma.real,gamma.est,gamma.adjust)

  keep <- as.matrix(cbind(zi,real.beta.b))
keep
  
}

check.1.mccue <- function (mean.beta.b.squiggle=.5,mean.beta.w.squiggle=.5,sigmasq.beta.b.squiggle=.01,sigmasq.beta.w.squiggle=.01,rho.bw.squiggle=0) {

  ## NOTE: variances are passed, not standard deviations
  
  n_5000                                # number of simulated districts
  alpha_0                               # second stage parameters
  gammacoef_1

  ## 1.  set psi squiggle parameters

  covar.bw.squiggle_
    rho.bw.squiggle*sqrt(sigmasq.beta.b.squiggle)*sqrt(sigmasq.beta.w.squiggle)
 
  ## 2. get psi parameters via simuation

  mu_c(mean.beta.b.squiggle,mean.beta.w.squiggle) # form mean 
  sig_matrix(nrow=2,ncol=2,             # and covariance matrices of squiggle normal
             c(sigmasq.beta.b.squiggle,covar.bw.squiggle,covar.bw.squiggle,sigmasq.beta.w.squiggle))

  temp.data_rmultnorm(n=50000,mu=mu,vmat=sig) # get normal draws from squiggle
  pitch_(temp.data[,1]<0 | temp.data[,1]>1 | temp.data[,2]<0 | temp.data[,2]>1)
  cat ("Throwing away ",sum(pitch==1)," observations...\n")
  temp.data_temp.data[as.logical(1-pitch),] # pitch the bad rows based on [0,1]

  mean.beta.b_mean(temp.data[,1])       # these are the non-squiggle 
  mean.beta.w_mean(temp.data[,2])       # parameters
  sigmasq.beta.b_var(temp.data[,1])
  sigmasq.beta.w_var(temp.data[,2])
  rho.bw_cor(temp.data[,1],temp.data[,2])
  covar.bw_cov(temp.data[,1],temp.data[,2])
  
  index_c(1:length(temp.data[,1]))      # list of numbers, length of temp.data
  use.these.observations_sample(index,size=n,replace=F)
    
  real.beta.b_temp.data[use.these.observations,1]
  real.beta.w_temp.data[use.these.observations,2]
  
  ## 3. get random xi and implied new ti

  xi_runif(n,min=0,max=1)
  
  ti_real.beta.b*xi+real.beta.w*(1-xi)
  
  ## 4.  calculate estimated beta.b and its estimation error.

  cat ("Getting ancillary parameter values...\n")

  mui <- xi*mean.beta.b+(1-xi)*mean.beta.w
  alphaib <- (xi*sigmasq.beta.b+(1-xi)*covar.bw)/(xi^2*sigmasq.beta.b+(1-xi)^2*sigmasq.beta.w+2*xi*(1-xi)*covar.bw)

  est.beta.b_mean.beta.b+alphaib*(ti-mui)
  error.beta.b_est.beta.b-real.beta.b
  
  ## 5. get implied covariate vector

  zetai_rnorm(n,mean=0,sd=1)            # second stage disturbance vector

  ## zi_c(1:n)
  ## zi[real.beta.b>=.75]_real.beta.b[real.beta.b>=.75]
  ## zi[real.beta.b<.75 && real.beta.b>=.5]_.5*real.beta.b[real.beta.b<.75 && real.beta.b>=.5]
  ## zi[real.beta.b<.5]_.45*real.beta.b[real.beta.b<.5]

  zi_real.beta.b+rnorm(n,mean=0,sd=.5)
  
  fit.real_lm(real.beta.b~zi)
  gamma.real_fit.real$coef[2]
  fit.est_lm(est.beta.b~zi)
  gamma.est_fit.est$coef[2]
  
  fit.temp_lm(error.beta.b~real.beta.b)
  delta.b.zero_fit.temp$coef[1]
  delta.b.one_fit.temp$coef[2]

  gamma.adjust_gamma.est/(1+delta.b.one)

  c(gamma.real,gamma.est,gamma.adjust)
  
}
