sim.xchange.king _ function (mean.beta.b.squiggle,mean.beta.w.squiggle,sigma.beta.b.squiggle,sigma.beta.w.squiggle,rho.bw.squiggle) {

  ## Step 1: assign parameter values
    
  n_20000                               # sample size
  
  sigmasq.beta.b.squiggle_sigma.beta.b.squiggle^2
  sigmasq.beta.w.squiggle_sigma.beta.w.squiggle^2
  
  covar.bw.squiggle_                    # get the untruncated covariance
    rho.bw.squiggle*sigma.beta.b.squiggle*sigma.beta.w.squiggle

  ## Step 1.5: get unsquiggle parameters based on draws from a squiggle normal
  ## distribution
  
  mu_c(mean.beta.b.squiggle,mean.beta.w.squiggle) # form mean 
  sig_matrix(nrow=2,ncol=2,             # and covariance matrices of squiggle normal
             c(sigmasq.beta.b.squiggle,covar.bw.squiggle,covar.bw.squiggle,sigmasq.beta.w.squiggle))

  temp.data_rmultnorm(n=200000,mu=mu,vmat=sig) # get normal draws from squiggle
  pitch_(temp.data[,1]<0 | temp.data[,1]>1 | temp.data[,2]<0 | temp.data[,2]>1)
  cat ("Throwing away ",sum(pitch==1)," observations...\n")
  temp.data_temp.data[as.logical(1-pitch),] # pitch the bad rows based on [0,1]

  mean.beta.b_mean(temp.data[,1])       # get truncated parameters
  mean.beta.w_mean(temp.data[,2])       # based on moments of the
  sigmasq.beta.b_var(temp.data[,1])     # non-pitched observations
  sigmasq.beta.w_var(temp.data[,2])
  rho.bw_cor(temp.data[,1],temp.data[,2])
  covar.bw_var(temp.data[,1],temp.data[,2])
  
  ## Step 2: draw xi values

  cat ("Getting x values...\n")
  xi_runif(n)
  xi_xi/10+.9

  ## Step 3: draw n precinct values for betaib and betaiw based on truncated parameters.
  ## To do this, take a random sample of n values from temp.data which
  ## already reflects the truncation at [0,1].  Recall that these were
  ## originally draw in an untruncated fashion.  This step will break down
  ## and quit with an error message if the length of temp.data is < n.
  
  if (length(temp.data[,1])<n) {
    stop (message="Not enough truncated data to generate beta values.")
  }
  
  index_c(1:length(temp.data[,1]))      # list of numbers, length of temp.data
  use.these.observations_sample(index,size=n,replace=F)

  real.beta.b_temp.data[use.these.observations,1]
  real.beta.w_temp.data[use.these.observations,2]

  ## Step 4: calculate ti based on the accounting identity (ie page 40)

  cat ("Getting t values...\n")
  ti_real.beta.b*xi+real.beta.w*(1-xi)

  ## Step 5: calculate auxiliary parameters based on squiggle values

  omegai_sigmasq.beta.b.squiggle*xi+covar.bw.squiggle*(1-xi) # page 108
  epsiloni_ti-mean.beta.b.squiggle*xi-mean.beta.w.squiggle*(1-xi) # page 108
  sigmasqi_sigmasq.beta.w.squiggle+     # page 106
    (2*covar.bw.squiggle-2*sigmasq.beta.w.squiggle)*xi+
    (sigmasq.beta.b.squiggle+sigmasq.beta.w.squiggle-2*covar.bw.squiggle)*(xi^2)
  
  ## Step 6: calculate estimated betab and its estimation error.  To do this,
  ## we first calculate the mean and variance terms from equation C.1 on page 304.
  ## These we call bigmu and bigsigmasq.  Then,  calculate the truncation points based
  ## on page 79.  Then, using eq 13.134 of Johnson, Kotz, and Balakrishnan
  ## Vol 1 page 156, we calculate the mean of the truncated normal.

  cat ("Getting ancillary parameter values...\n")
  
  bigmu_mean.beta.b.squiggle+(omegai/sigmasqi)*epsiloni
  bigsigmasq_sigmasq.beta.b.squiggle-omegai^2/sigmasqi

  ## now get bounds (p. 79)

  n_length(xi)

  zeros_rep(0,times=n)
  templow_rbind(zeros,(ti-(1-xi))/xi)
  lower_apply (templow,2,max)

  ones_rep(1,times=n)
  temphigh_rbind(ones,ti/xi)
  upper_apply(temphigh,2,min)

  ## set temporary parameters

  bigsigma_sqrt(bigsigmasq)             # take the square root only once!
  aterm_(lower-bigmu)/bigsigma
  bterm_(upper-bigmu)/bigsigma

  est.beta.b_bigmu+(dnorm(aterm)-dnorm(bterm))/(pnorm(bterm)-pnorm(aterm))*bigsigma
  ## note: do not need this one
  ##  est.beta.w_ti/(1-xi)-est.beta.b*xi/(1-xi) 
    
  error.b_est.beta.b-real.beta.b

  cat ("Fitting the error regression...\n")
  fit_lm(error.b~real.beta.b)
  tstat1_fit$coef[1]/sqrt(summary(fit)$cov.unscale[1,1]*summary(fit)$sigma^2)
  tstat2_fit$coef[2]/sqrt(summary(fit)$cov.unscale[2,2]*summary(fit)$sigma^2)
  sigmasq_summary(fit)$sigma^2

  cat ("deltabzero is ",fit$coef[1])
  cat ("\ndeltabone is ",fit$coef[2],"\n\n")

  result <- c(fit$coef[2],tstat2,sigmasq)
  names(result) <- c("deltabone","tstat","sigmasq")
  print (result)
  result
  
}
