sim.xchange.mccue _ function (mean.beta.b.squiggle,mean.beta.w.squiggle,sigma.beta.b.squiggle,sigma.beta.w.squiggle,rho.bw.squiggle) {

  ## Step 1: assign parameter values

  n_20000                               # sample size
  
  sigmasq.beta.b.squiggle_sigma.beta.b.squiggle^2 # get untruncated variances
  sigmasq.beta.w.squiggle_sigma.beta.w.squiggle^2
  
  covar.bw.squiggle_                    # get the untruncated covariance
    rho.bw.squiggle*sigma.beta.b.squiggle*sigma.beta.w.squiggle

  ## Step 1.5: get unsquiggle parameters based on draws from a squiggle normal
  ## distribution (ie, get truncated parameters based on untruncated ones)

  mu_c(mean.beta.b.squiggle,mean.beta.w.squiggle) # form mean 
  sig_matrix(nrow=2,ncol=2,             # and covariance matrices of squiggle normal
             c(sigmasq.beta.b.squiggle,covar.bw.squiggle,covar.bw.squiggle,sigmasq.beta.w.squiggle))

  temp.data_rmultnorm(n=200000,mu=mu,vmat=sig) # get normal draws from squiggle normal
  pitch_(temp.data[,1]<0 | temp.data[,1]>1 | temp.data[,2]<0 | temp.data[,2]>1)
  cat ("Throwing away ",sum(pitch==1)," observations...\n")
  temp.data_temp.data[as.logical(1-pitch),] # pitch the bad rows based on [0,1]

  mean.beta.b_mean(temp.data[,1])       # get truncated parameters
  mean.beta.w_mean(temp.data[,2])       # based on moments of the
  sigmasq.beta.b_var(temp.data[,1])     # non-pitched observations
  sigmasq.beta.w_var(temp.data[,2])
  rho.bw_cor(temp.data[,1],temp.data[,2])
  covar.bw_var(temp.data[,1],temp.data[,2])
  
  ## Step 2: draw xi values

  cat ("Getting x values...\n")
  xi_runif(n)
  xi_xi/10+.9

  ## Step 3: draw n precinct values for betaib and betaiw based on
  ## untruncated parameters

  index_c(1:length(temp.data[,1]))      # list of numbers, length of temp.data
  use.these.observations_sample(index,size=n,replace=F)

  real.beta.b_temp.data[use.these.observations,1]
  real.beta.w_temp.data[use.these.observations,2]

  ## Step 4: calculate ti based on the accounting identity

  cat ("Getting t values...\n")
  ti_real.beta.b*xi+real.beta.w*(1-xi)

  ## Step 5: calculate auxiliary parameters use in the mccue estimator

  mui <- xi*mean.beta.b+(1-xi)*mean.beta.w
  alphaib <- (xi*sigmasq.beta.b+(1-xi)*covar.bw)/(xi^2*sigmasq.beta.b+(1-xi)^2*sigmasq.beta.w+2*xi*(1-xi)*covar.bw)
  
  ## Step 6: calculate estimated betab and its estimation error. 
  est.beta.b_mean.beta.b+alphaib*(ti-mui)
  error.b_est.beta.b-real.beta.b

  cat ("Fitting the error regression...\n")
  fit_lm(error.b~real.beta.b)
  tstat1_fit$coef[1]/sqrt(summary(fit)$cov.unscale[1,1]*summary(fit)$sigma^2)
  tstat2_fit$coef[2]/sqrt(summary(fit)$cov.unscale[2,2]*summary(fit)$sigma^2)
  sigmasq_summary(fit)$sigma^2

  cat ("deltabzero is ",fit$coef[1])
  cat ("\ndeltabone is ",fit$coef[2],"\n\n")

  result <- c(fit$coef[2],tstat2,sigmasq)
  names(result) <- c("deltabone","tstat","sigmasq")
  print (result)
  result
  
}
